@@ -3,7 +3,6 @@
 from zeroconf import ServiceInfo, Zeroconf
 import json
 import socket
-import sys
 import tornado.concurrent
 import tornado.gen
 import tornado.httpserver
@@ -859,6 +858,7 @@ class WebThingServer:
             '{}._webthing._tcp.local.'.format(self.name),
         ]
         kwargs = {
+            'addresses': [socket.inet_aton(get_ip())],
             'port': self.port,
             'properties': {
                 'path': '/',
@@ -866,10 +866,8 @@ class WebThingServer:
             'server': '{}.local.'.format(socket.gethostname()),
         }
 
-        if sys.version_info.major == 3:
-            kwargs['addresses'] = [socket.inet_aton(get_ip())]
-        else:
-            kwargs['address'] = socket.inet_aton(get_ip())
+        if self.app.is_tls:
+            kwargs['properties']['tls'] = '1'
 
         self.service_info = ServiceInfo(*args, **kwargs)
         self.zeroconf = Zeroconf()
